package com.ruoyi.business.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.business.domain.HwDevice;
import com.ruoyi.business.domain.VO.DeviceModeVo;
import com.ruoyi.business.domain.VO.HwDeviceVo;
import com.ruoyi.business.domain.VO.HwMonitorUnitVo;
import com.ruoyi.common.datascope.annotation.DataScope;


/**
 * 设备信息Service接口
 *
 * @author xins
 * @date 2023-08-24
 */
public interface IHwDeviceService
{
    /**
     * 查询设备信息
     *
     * @param deviceId 设备信息主键
     * @return 设备信息
     */
    public HwDevice selectHwDeviceByDeviceId(Long deviceId);

    /**
     * 查询设备信息，返回监控单元名称
     *
     * @param deviceId 设备信息主键
     * @return 设备信息
     */
    public HwDevice selectHwDeviceJoinByDeviceId(Long deviceId);

    /**
     * 查询3.	设备各类型占所有设备数量百分比饼状图（左下角）
     * */
    public List<DeviceModeVo> selectDeviceModeNameVo();

    /**
     * 查询设备信息列表
     *
     * @param hwDevice 设备信息
     * @return 设备信息集合
     */
    public List<HwDevice> selectHwDeviceList(HwDevice hwDevice);

    /**
     * 查询关联设备信息列表
     *
     * @param deviceId 设备信息主键
     * @return 设备信息
     */
    public List<HwDevice> selectLinkDeviceList(Long deviceId);

    /**
     * 新增设备信息
     *
     * @param hwDevice 设备信息
     * @return 结果
     */
    public int insertHwDevice(HwDevice hwDevice);

    /**
     * 修改设备信息
     *
     * @param hwDevice 设备信息
     * @return 结果
     */
    public int updateHwDevice(HwDevice hwDevice);

    /**
     * 批量删除设备信息
     *
     * @param deviceIds 需要删除的设备信息主键集合
     * @return 结果
     */
    public int deleteHwDeviceByDeviceIds(Long[] deviceIds);

    /**
     * 删除设备信息信息
     *
     * @param deviceId 设备信息主键
     * @return 结果
     */
    public int deleteHwDeviceByDeviceId(Long deviceId);


    /**
     * @return Map<String,List<HwDeviceVo>>
     * @description 设备监测页面，根据监控单元获取设备监控信息
     * @author xins
     * @date 2023-09-15 16:59
     */
    public Map<String,List<HwDeviceVo>> getDevicesByMonitor(HwDevice queryHwDevice);

    /**
     * 查询设备信息列表,join监控单元、设备模型等表
     *
     * @param hwDevice 设备信息
     * @return 设备信息
     */

    public List<HwDevice> selectHwDeviceJoinList(HwDevice hwDevice);
}
