package com.ruoyi.business.controller;

import java.util.Date;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.business.domain.HwDeviceMode;
import com.ruoyi.business.domain.HwMonitorUnit;
import com.ruoyi.business.domain.HwScene;
import com.ruoyi.business.domain.VO.DeviceModeVo;
import com.ruoyi.business.domain.VO.HwMonitorUnitVo;
import com.ruoyi.business.service.IHwDeviceModeService;
import com.ruoyi.business.service.IHwMonitorUnitService;
import com.ruoyi.business.service.IHwSceneService;
import com.ruoyi.common.core.constant.HwDictConstants;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.domain.SysDept;
import com.ruoyi.system.api.domain.SysRole;
import com.ruoyi.system.api.domain.SysUser;
import com.ruoyi.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.business.domain.HwDevice;
import com.ruoyi.business.service.IHwDeviceService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 设备信息Controller
 *
 * @author xins
 * @date 2023-08-24
 */
@RestController
@RequestMapping("/device")
public class HwDeviceController extends BaseController
{
    @Autowired
    private IHwDeviceService hwDeviceService;

    @Autowired
    private IHwMonitorUnitService hwMonitorUnitService;

    @Autowired
    private IHwDeviceModeService hwDeviceModeService;

    @Autowired
    private IHwSceneService hwSceneService;

    /**
     * 查询设备信息列表
     */
    @RequiresPermissions("business:device:list")
    @GetMapping("/list")
    public TableDataInfo list(HwDevice hwDevice)
    {
        startPage();
        List<HwDevice> list = hwDeviceService.selectHwDeviceJoinList(hwDevice);
        return getDataTable(list);
    }




    /**
     * 导出设备信息列表
     */
    @RequiresPermissions("business:device:export")
    @Log(title = "设备信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HwDevice hwDevice)
    {
        List<HwDevice> list = hwDeviceService.selectHwDeviceList(hwDevice);
        ExcelUtil<HwDevice> util = new ExcelUtil<HwDevice>(HwDevice.class);
        util.exportExcel(response, list, "设备信息数据");
    }

    /**
     * 获取设备信息详细信息
     */
    @RequiresPermissions("business:device:query")
    @GetMapping(value = "/{deviceId}")
    public AjaxResult getInfo(@PathVariable("deviceId") Long deviceId)
    {
        return success(hwDeviceService.selectHwDeviceByDeviceId(deviceId));
    }

    /**
     * 新增设备信息
     */
    @RequiresPermissions("business:device:add")
    @Log(title = "设备信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HwDevice hwDevice)
    {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = loginUser.getSysUser();
        hwDevice.setTenantId(user.getTenantId());
        hwDevice.setCreateBy(user.getUserName());
        return toAjax(hwDeviceService.insertHwDevice(hwDevice));
    }

    /**
     * 修改设备信息
     */
    @RequiresPermissions("business:device:edit")
    @Log(title = "设备信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HwDevice hwDevice)
    {
        hwDevice.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(hwDeviceService.updateHwDevice(hwDevice));
    }

    /**
     * 删除设备信息
     */
    @RequiresPermissions("business:device:remove")
    @Log(title = "设备信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceIds}")
    public AjaxResult remove(@PathVariable Long[] deviceIds)
    {
        return toAjax(hwDeviceService.deleteHwDeviceByDeviceIds(deviceIds));
    }


    @RequiresPermissions("business:device:list")
    @GetMapping("/getScenes")
    public AjaxResult getScenes(HwScene scene)
    {
        return success(hwSceneService.selectHwSceneList(scene));
    }

    /**
     * 获取监控单元树列表
     */
    @RequiresPermissions("business:device:list")
    @GetMapping(value = {"/monitorUnitTree/", "/monitorUnitTree/{sceneId}"})
    public AjaxResult monitorUnitTree(@PathVariable(value = "sceneId", required = false) Long sceneId)
    {
        HwMonitorUnit queryMonitorUnit = new HwMonitorUnit();
        queryMonitorUnit.setSceneId(sceneId);
        return success(hwMonitorUnitService.selectMonitorTreeList(queryMonitorUnit));
    }

    @RequiresPermissions("business:device:list")
    @GetMapping(value = {"/getDeviceModes/", "/getDeviceModes/{sceneId}"})
    public AjaxResult getDeviceModes(@PathVariable(value = "sceneId", required = false) Long sceneId)
    {
        HwDeviceMode queryDeviceMode = new HwDeviceMode();
        queryDeviceMode.setSceneId(sceneId);
        return success(hwDeviceModeService.selectHwDeviceModeList(queryDeviceMode));
    }

    @RequiresPermissions("business:device:list")
    @GetMapping(value = {"/getGatewayDevices/", "/getGatewayDevices/{sceneId}"})
    public AjaxResult getGatewayDevices(@PathVariable(value = "sceneId", required = false) Long sceneId)
    {
        HwDevice queryHwDevice = new HwDevice();
        queryHwDevice.setSceneId(sceneId);
        queryHwDevice.setDeviceType(HwDictConstants.DEVICE_TYPE_GATEWAY_DEVICE);
        return success(hwDeviceService.selectHwDeviceList(queryHwDevice));
    }


    /**
     * 状态修改
     */
    @RequiresPermissions("business:device:edit")
    @Log(title = "设备管理", businessType = BusinessType.UPDATE)
    @PutMapping("/changeDeviceStatus")
    public AjaxResult changeDeviceStatus(@RequestBody HwDevice device)
    {
        device.setUpdateBy(SecurityUtils.getUsername());
        device.setUpdateTime(new Date());
        return toAjax(hwDeviceService.updateHwDevice(device));
    }

}
